@@ -55,11 +55,13 @@ class ConfigUtils:
                 for k, v in config_json[key].items():
                     real_value[k] = v
                 for ek, ev in extend_json.items():
-                    real_value[ek] = ev
+                    if ek not in real_value.keys():
+                        real_value[ek] = ev
                 config_json[real_key] = real_value
                 config_json.pop(key)
         for bk in basic_keys:
-            config_json.pop(bk)
+            if bk in config_json.keys():
+                config_json.pop(bk)
         return config_json
 
     @classmethod
